@@ -6,6 +6,7 @@ import scipy.optimize as spo
 from scipy.optimize import curve_fit
 import scipy.odr as sco
 from itertools import chain
+import nanoscipy.mathpar as nsp
 
 standardColorsHex = ['#5B84B1FF', '#FC766AFF', '#5F4B8BFF', '#E69A8DFF',
                      '#42EADDFF', '#CDB599FF', '#00A4CCFF', '#F95700FF',
@@ -191,8 +192,9 @@ class DatAn:
                 scipy.optimize.fsolve, where it is required. Therefore, if multiple results are expected, this may be a 
                 list of lists. The default is 1.
             sec_opr : str, optional
-                Perform a secondary operation on the primary operation. Supported operations are: **, *, /, ln, log, and
-                exp. The default is None.
+                Perform a secondary operation on the primary operation. This type is denoted as a string, with the 
+                primary operation denoted as 'x', e.g., 'x^-1'. Supported operations: '^', '*', '/', '+', '-', 'ln', 
+                 'log' (this is log10), 'exp', 'sin', 'cos', 'tan', 'pi'. The default is None.
             oprint : str, optional
                 Print the results from the operation. If 'all', print results for operation on all fitted functions, if
                 a letter, print result for that particular fitted function, else does not print. Note that if the
@@ -235,30 +237,39 @@ class DatAn:
             raise TypeError(f'Operation, {operation}, is invalid.')
 
         # perform secondary operation if any is given
-        oprRes = []
-        if not sec_opr:
-            oprRes = [i for i in oprResPre]
+        opr_res = []
+        if sec_opr:
+            decomposed_sec_opr = [i for i in sec_opr]  # decompose string into list
+            prim_opr_id = nsf.find(decomposed_sec_opr, 'x')  # find indexes for 'x'
+
+            # determine whether the found 'x' is part of 'exp'
+            fixed_opr_id = []
+            for i in prim_opr_id:
+                ip1 = im1 = None
+                try:
+                    ip1 = decomposed_sec_opr[i + 1]
+                except IndexError:
+                    pass
+                try:
+                    im1 = decomposed_sec_opr[i - 1]
+                except IndexError:
+                    pass
+
+                if im1 != 'e' and ip1 != 'p':
+                    fixed_opr_id.append(i)
+
+            # replace 'x' with the primary operation result
+            replaced_decom_string = [
+                [[k if i in fixed_opr_id else j for i, j in nsf.indexer(decomposed_sec_opr)] for
+                 k in l] for l in oprResPre]
+
+            # convert list back to a string, and execute operations in parser
+            oprRes = [[nsp.parser(nsf.list_to_string(j)) for j in i] for i in replaced_decom_string]
+            finalOperation = nsf.list_to_string([operation if i in fixed_opr_id else e for i, e in
+                                                 nsf.indexer(decomposed_sec_opr)])
+        else:
             finalOperation = operation
-        elif '**' in sec_opr:
-            warnings.warn('Operations such as **(1/3) with parenthesizes are currently not yet supported', stacklevel=2)
-            oprRes = [i ** float(sec_opr.strip('**')) for i in oprResPre]
-            finalOperation = operation + sec_opr
-        elif '*' in sec_opr:
-            warnings.warn('Operations such as *(1/3) with parenthesizes are currently not yet supported', stacklevel=2)
-            oprRes = [i * float(sec_opr.strip('*')) for i in oprResPre]
-            finalOperation = operation + sec_opr
-        elif '/' in sec_opr:
-            oprRes = [i / float(sec_opr.strip('/')) for i in oprResPre]
-            finalOperation = operation + sec_opr
-        elif sec_opr == 'ln':
-            oprRes = [np.log(i) for i in oprResPre]
-            finalOperation = f'ln({operation})'
-        elif sec_opr == 'log':
-            oprRes = [np.log10(i) for i in oprResPre]
-            finalOperation = f'log({operation})'
-        elif sec_opr == 'exp':
-            oprRes = [np.exp(i) for i in oprResPre]
-            finalOperation = f'exp({operation})'
+            oprRes = oprResPre
 
         # print results if oprint is set to valid value
         #   first, check if costum data labels have been defined from .plot()
@@ -409,6 +420,8 @@ class DatAn:
                 Set whether uncertainties for the fits should be plotted. The default is True.
             axis : int
                 Set whether plot should have axis marked. Three different styles: 0, 1, 2. The default is None.
+            save_to : str
+                String with a path and filename to save figure to.
 
 
         Returns
@@ -662,4 +675,7 @@ class DatAn:
             legend_loc = 'best'
         ax.legend(fontsize=legend_size, loc=legend_loc)
         plt.rcParams.update({'font.family': 'Times New Roman'})
+        if 'save_to' in kwargs.keys():  # if save_to key, save to that path
+            save_to = kwargs.get('save_to')
+            plt.savefig(save_to, dpi=set_dpi)
         plt.show()
